@@ -1,6 +1,8 @@
 from tokenizer_tools.conllz.sentence import Sentence, SentenceX
+import pytest
 
 
+@pytest.mark.skip("")
 def test_write_as_row():
     s = Sentence(["1"], ["cfv", "dddwedwf"], ["cfv"], 4)
     data = ["a", "b", "c"]
