@@ -6,6 +6,13 @@ from tokenizer_tools.tagset.offset.sequence import Sequence
 
 
 class Document(Sequence):
+    def __init__(self, text, span_set=None, id=None, label=None, extra_attr=None):
+        super().__init__(
+            text, span_set=span_set, id=id, label=label, extra_attr=extra_attr
+        )
+
+        self._block_view = None
+
     @property
     def intent(self):
         return self.extra_attr.get("intent")
@@ -98,3 +105,34 @@ class Document(Sequence):
             tags[span.start : span.end] = encoder.encode(span.value)
 
         return tags
+
+    def get_entities_by_range(self, start: int, end: int):
+        result = []
+
+        for span in self.span_set.sort_by_location():
+            if span.end > start and span.end <= end:
+                result.append(span)
+            elif span.start >= start and span.start < end:
+                result.append(span)
+
+        return result
+
+    def as_block_view(self):
+        from tokenizer_tools.tagset.offset.document_block_view import DocumentBlockView
+
+        if self._block_view is None:
+            self._block_view = DocumentBlockView(self)
+
+        return self._block_view
+
+    def _notify_block_view(self):
+        self._block_view._notify()
+
+    @classmethod
+    def from_markdown(cls, text) -> "Document":
+        """Create Document object from Markdown format
+
+        parse Markdown string like: `[明天](日期)下雨吗？` into Document object
+        """
+
+        raise NotImplementedError()
